betty.project.extension.deriver package - Betty documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# betty.project.extension.deriver package

## Module contents

Expand an ancestry by deriving additional data from existing data.

final class betty.project.extension.deriver.Deriver

  Bases: `ShorthandPluginBase`, `Extension`

  Expand an ancestry by deriving additional data from existing data.

  classmethod comes_before() → set[PluginIdentifier[Extension]]

    Get the plugins that this plugin comes before.

    The returned plugins come after this plugin.

  register_event_handlers(registry: EventHandlerRegistry) → None

    Register event handlers with the project.